@@ -22,7 +22,7 @@ class EditorPage : public GrantleeThemeEditor::EditorPage
     Q_OBJECT
 public:
     explicit EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QString &projectDirectory, QWidget *parent = nullptr);
-    ~EditorPage();
+    ~EditorPage() override;
 
     ContactPrintThemePreview *preview() const;
 
